==> humhub-1.4.2.tar.gz: humhub-1.4.2/protected/humhub/modules/admin/messages/fa-IR/settings.php <==
<?php
return array (
  '1 month' => '',
  '1 week' => '',
  '1 year' => '',
  '2 weeks' => '',
  '3 months' => '',
  '6 months' => '',
  '<strong>Confirm</strong> icon deletion' => '',
  '<strong>Confirm</strong> image deletion' => '',
  'APC(u)' => '',
  'Add OEmbed provider' => 'OEmbedاضافه کردن بوجود آورنده',
  'Add new provider' => 'اضافه کردن تامی‌کننده‌ی جدید',
  'Advanced Settings' => 'تنظیمات پیشرفته',
  'Allow Self-Signed Certificates?' => 'مدارک امضاشده توسط خود فرد مجاز باشد؟',
  'Allowed file extensions' => 'پسوندهای مجاز فایل',
  'Alphabetical' => 'الفبایی',
  'Appearance Settings' => 'تنظیمان ظاهر',
  'Back to overview' => 'برگشت به دید کلی',
  'Base URL' => 'آدرس پایه',
  'Cache Backend' => 'ذخیره‌ی اطلاعات سمت سرور در حافظه‌ی موقت',
  'Comma separated list. Leave empty to allow all.' => 'لیست جدا‌شده با کاما. برای اجازه‌ی همه خالی بگذارید.',
  'Convert command not found!' => 'دستور تبدیل یافت نشد!',
  'Current Image Library: {currentImageLibrary}' => 'کتابخانه‌ی عکس کنونی: {currentImageLibrary}',
  'Currently no provider active!' => 'در حال حاضر هیچ تامین‌کننده‌ای فعال نیست!',
  'Currently there are {count} records in the database dating from {dating}.' => '',
  'Dashboard' => 'خانه',
  'Date input format' => 'فرمت ورود تاريخ',
  'Default Expire Time (in seconds)' => 'زمان انقضای پیش‌فرض (ثانیه)',
  'Default language' => 'زبان پیش‌فرض',
  'Default pagination size (Entries per page)' => 'سایز صفحه‌بندی پیش‌فرض (ورودی برای هر صفحه)',
  'Default stream content order' => 'ترتيب محتواي پيش فرض',
  'Delete' => 'حذف',
  'Display Name (Format)' => 'نمایش نام (فرمت)',
  'Dropdown space order' => 'ترتیب انجمن‌های لیست',
  'E-Mail' => 'ایمیل',
  'E-Mail sender address' => 'آدرس فرستنده‌ی ایمیل',
  'E-Mail sender name' => 'نام فرستنده‌ی ایمیل',
  'E.g. http://example.com/humhub' => 'برای مثال http://example.com/humhub',
  'Edit OEmbed provider' => 'OEmbedویرایش بوجود آورنده',
  'Enable user friendship system' => 'فعال كردن سيستم دوستيابي',
  'Enabled' => 'فعال شد',
  'Enabled OEmbed providers' => 'را فعال کن OEmbed بوجود ورندگان',
  'Encryption' => 'رمزگذاری',
  'Endpoint Url' => 'Endpoint Url',
  'File' => 'فايل',
  'Firstname Lastname (e.g. John Doe)' => 'نام نام‌خانوادگی (مانند John Doe)',
  'Friendship' => 'دوستی',
  'General' => 'کلی',
  'General Settings' => 'تنظیمات کلی',
  'Got invalid image magick response! - Correct command?' => 'پاسخ نامعتبر image magick دریافت شد! - آیا دستور درست است؟',
  'HTML tracking code' => 'کد رهگیری HTML',
  'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'اینجا می توانید تنظیمات ثبت نام و تنظیمات اضافی هنگام ثبت نام را تغییر دهید',
  'Here you can configure basic settings of your social network.' => 'اینجا می تانید تنظیمات پایه سایت را تغییر دهید',
  'Hide file info (name, size) for images on wall' => 'اطلاعات فایل (نام، سایز) را برای عکس‌های روی صفحه‌ی اعلانات پنهان کن',
  'Horizontal scrolling images on a mobile device' => '',
  'Icon upload' => '',
  'If not set, height will default to 200px.' => 'در صورت مشخص نکردن، ارتفاع مقدار پیش‌فرض ۲۰۰ پیکسل خواهد بود.',
  'If not set, width will default to 200px.' => 'در صورت مشخص نکردن، عرض مقدار پیش‌فرض ۲۰۰ پیکسل خواهد بود.',
  'Image Magick convert command (optional)' => 'دستور تبدیل image magick (دلخواه)',
  'Last visit' => 'آخرین مشاهده',
  'Logo upload' => 'بارگذاری لوگو',
  'Mail Transport Type' => 'نوع انتقال نامه',
  'Maximum allowed age for logs.' => '',
  'Maximum preview image height (in pixels, optional)' => 'ماکزیمم ارتفاع نمایش عکس (پیکسل، دلخواه)',
  'Maximum preview image width (in pixels, optional)' => 'ماکزیمم عرض نمایش عکس (پیکسل، دلخواه)',
  'Maximum upload file size (in MB)' => 'ماکزیمم سایز بارگذاری فایل (MB)',
  'Name of the application' => 'نام برنامه‌ی کاربردی',
  'No Proxy Hosts' => 'میزبان‌های پراکسی وجود ندارند',
  'No caching' => '',
  'None - shows dropdown in user registration.' => 'None - shows dropdown in user registration.',
  'Notification Settings' => '',
  'Old logs can significantly increase the size of your database while providing little information.' => '',
  'PHP APC(u) Extension missing - Type not available!' => '',
  'PHP reported a maximum of {maxUploadSize} MB' => 'PHP ماکزیمم را {maxUploadSize} مگابایت گزارش کرد.',
  'Password' => 'گذرواژه',
  'Port' => 'درگاه',
  'Port number' => 'شماره‌ی درگاه',
  'Redis' => '',
  'SMTP Options' => 'اختیارات SMTP',
  'Save' => 'ذخیره',
  'Save & Flush Caches' => 'ذخیره و تخلیه‌ی حافظه‌ی موقت',
  'Saved' => 'ذخیره شد.',
  'Saved and flushed cache' => 'ذخیره شد و حافظه‌ی موقت خالی شد.',
  'Server' => 'سرور',
  'Server Timezone' => 'محدوده زماني سرور',
  'Show introduction tour for new users' => 'نمایش تور معرفی برای کاربران جدید',
  'Show user profile post form on dashboard' => 'فرم پست پروفایل کاربر را در خانه نمایش بده',
  'Sort by creation date' => 'دسته بندي بر اساس تاريخ خاصي',
  'Sort by update date' => 'دسته بندي بر اساس تاريخ بروزرساني',
  'Theme' => 'ظاهر',
  'These settings refer to advanced topics of your social network.' => 'این تنظیمات مربوط به موضوعات پیشرفته سایت می شود',
  'These settings refer to the appearance of your social network.' => 'این تنظیمات مربوط به ظاهر سایت می شود',
  'Url Prefix' => 'پیشوند آدرس',
  'Url Prefix without http:// or https:// (e.g. youtube.com)' => 'پیشوند آدرس بدون http:// یا https:// (مانند youtube.com)',
  'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => '%url% را به عنوان مقدار پیشنهادی برای 
آدرس قرار بده. فرمت باید JSON باشد. (برای مثال http://youtube.com/oembed?url=%url%format=json)',
  'Use X-Sendfile for File Downloads' => 'برای دانلود فایل‌ از X-Sendfile استفاده کنید ',
  'User' => 'کاربر',
  'User Settings' => 'تنظیمات کاربری',
  'Username' => 'نام کاربری',
  'Username (e.g. john)' => 'نام کاربری (مانند John)',
  'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => '',
  'never' => 'هرگز',
);

==> humhub-1.5.2.tar.gz: humhub-1.5.2/protected/humhub/modules/admin/messages/fa-IR/settings.php <==
<?php
return array (
  '1 month' => '۱ ماه',
  '1 week' => '۱ هفته',
  '1 year' => '۱ سال',
  '2 weeks' => '۲ هفته',
  '3 months' => '۳ ماه',
  '6 months' => '۶ ماه',
  '<strong>Confirm</strong> icon deletion' => '',
  '<strong>Confirm</strong> image deletion' => '',
  'APC(u)' => '',
  'Add OEmbed provider' => 'OEmbed افزودن فراهم‌کننده‌ی',
  'Add new provider' => 'افزودن فراهم‌کننده‌ی جدید',
  'Advanced Settings' => 'تنظیمات پیشرفته',
  'Allow Self-Signed Certificates?' => 'مدارک امضا شده توسط خود فرد مجاز باشد؟',
  'Allowed file extensions' => 'پسوندهای مجاز فایل',
  'Alphabetical' => 'الفبایی',
  'Appearance Settings' => 'تنظیمات ظاهری',
  'Auto format based on user language - Example: {example}' => 'فرمتگذاری بر اساس زبان کاربر برای مثال : {example}',
  'Back to overview' => 'برگشت به دید کلی',
  'Base URL' => 'آدرس پایه',
  'Cache Backend' => 'ذخیره‌ی اطلاعات سمت سرور در حافظه‌ی موقت',
  'Comma separated list. Leave empty to allow all.' => 'لیست جدا‌شده با کاما. برای اجازه‌ی همه خالی بگذارید.',
  'Could not send test email.' => '',
  'Currently no provider active!' => 'در حال حاضر هیچ فراهم‌کننده‌ای فعال نیست!',
  'Currently there are {count} records in the database dating from {dating}.' => '',
  'Dashboard' => 'خانه',
  'Date input format' => 'فرمت ورود تاریخ',
  'Default Expire Time (in seconds)' => 'زمان انقضای پیش‌فرض (ثانیه)',
  'Default language' => 'زبان پیش‌فرض',
  'Default pagination size (Entries per page)' => 'سایز صفحه‌بندی پیش‌فرض (ورودی برای هر صفحه)',
  'Default stream content order' => 'ترتیب محتوای پیش‌فرض',
  'Delete' => 'حذف',
  'Display Name (Format)' => 'نمایش نام (فرمت)',
  'Dropdown space order' => 'ترتیب انجمن‌های لیست',
  'E-Mail' => 'ایمیل',
  'E-Mail sender address' => 'آدرس فرستنده‌ی ایمیل',
  'E-Mail sender name' => 'نام فرستنده‌ی ایمیل',
  'E.g. http://example.com/humhub' => 'برای مثال http://example.com/humhub',
  'Edit OEmbed provider' => 'ویرایش فراهم‌کننده‌ی OEmbed',
  'Enable user friendship system' => 'فعال كردن سیستم دوست‌یابی',
  'Enabled' => 'فعال شد',
  'Enabled OEmbed providers' => 'را فعال کن OEmbed بوجود ورندگان',
  'Encryption' => 'رمزگذاری',
  'Endpoint Url' => 'Endpoint Url',
  'File' => 'پرونده',
  'Firstname Lastname (e.g. John Doe)' => 'نام نام‌خانوادگی (مانند John Doe)',
  'Fixed format (dd/mm/yyyy) - Example: {example}' => '',
  'Friendship' => 'دوستی',
  'General' => 'کلی',
  'General Settings' => 'تنظیمات کلی',
  'HTML tracking code' => 'کد رهگیری HTML',
  'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'اینجا می توانید تنظیمات ثبت نام و تنظیمات اضافی هنگام ثبت نام را تغییر دهید',
  'Here you can configure basic settings of your social network.' => 'اینجا می‌توانید تنظیمات پایه سایت را تغییر دهید',
  'Hide file info (name, size) for images on wall' => 'اطلاعات فایل (نام، سایز) را برای عکس‌های روی صفحه‌ی اعلانات پنهان کن',
  'Horizontal scrolling images on a mobile device' => '',
  'Icon upload' => '',
  'If not set, height will default to 200px.' => 'در صورت مشخص نکردن، ارتفاع مقدار پیش‌فرض ۲۰۰ پیکسل خواهد بود.',
  'If not set, width will default to 200px.' => 'در صورت مشخص نکردن، عرض مقدار پیش‌فرض ۲۰۰ پیکسل خواهد بود.',
  'Last visit' => 'آخرین مشاهده',
  'Logo upload' => 'بارگذاری لوگو',
  'Mail Transport Type' => 'نوع انتقال نامه',
  'Maximum allowed age for logs.' => '',
  'Maximum preview image height (in pixels, optional)' => 'ماکزیمم ارتفاع نمایش عکس (پیکسل، دلخواه)',
  'Maximum preview image width (in pixels, optional)' => 'ماکزیمم عرض نمایش عکس (پیکسل، دلخواه)',
  'Maximum upload file size (in MB)' => 'ماکزیمم سایز بارگذاری فایل (MB)',
  'Mobile appearance' => '',
  'Name of the application' => 'نام برنامه‌ی کاربردی',
  'No Proxy Hosts' => 'میزبان‌های پراکسی وجود ندارند',
  'No caching' => '',
  'None - shows dropdown in user registration.' => 'None - shows dropdown in user registration.',
  'Notification Settings' => '',
  'Old logs can significantly increase the size of your database while providing little information.' => '',
  'PHP APC(u) Extension missing - Type not available!' => '',
  'PHP reported a maximum of {maxUploadSize} MB' => 'PHP ماکزیمم را {maxUploadSize} مگابایت گزارش کرد.',
  'Password' => 'گذرواژه',
  'Port' => 'درگاه',
  'Port number' => 'شماره‌ی درگاه',
  'Prevent client caching of following scripts' => '',
  'Redis' => '',
  'SMTP Options' => 'اختیارات SMTP',
  'Save' => 'ذخیره',
  'Save & Flush Caches' => 'ذخیره و تخلیه‌ی حافظه‌ی موقت',
  'Save & Test' => 'ذخیره و آزمایش',
  'Saved' => 'ذخیره شد.',
  'Saved and flushed cache' => 'ذخیره شد و حافظه‌ی موقت خالی شد.',
  'Server' => 'سرور',
  'Server Timezone' => 'محدوده زمانی سرور',
  'Show introduction tour for new users' => 'نمایش تور معرفی برای کاربران جدید',
  'Show user profile post form on dashboard' => 'فرم پست پروفایل کاربر را در خانه نمایش بده',
  'Sort by creation date' => 'مرتب‌سازی با تاریخ ایجاد',
  'Sort by update date' => 'مرتب‌سازی با تاریخ به‌روزرسانی',
  'Test message' => '',
  'Theme' => 'قالب',
  'These settings refer to advanced topics of your social network.' => 'این تنظیمات مربوط به موضوعات پیشرفته سایت می شود',
  'These settings refer to the appearance of your social network.' => 'این تنظیمات مربوط به ظاهر سایت می شود',
  'Url Prefix' => 'پیشوند آدرس',
  'Url Prefix without http:// or https:// (e.g. youtube.com)' => 'پیشوند آدرس بدون http:// یا https:// (مانند youtube.com)',
  'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => '%url% را به عنوان مقدار پیشنهادی برای 
آدرس قرار بده. فرمت باید JSON باشد. (برای مثال http://youtube.com/oembed?url=%url%format=json)',
  'Use X-Sendfile for File Downloads' => 'برای دانلود فایل‌ از X-Sendfile استفاده کنید',
  'Use the default swipe to show sidebar on a mobile device' => '',
  'User' => 'کاربر',
  'User Settings' => 'تنظیمات کاربری',
  'Username' => 'نام کاربری',
  'Username (e.g. john)' => 'نام کاربری (مانند John)',
  'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => '',
  'You\'re using no icon at the moment. Upload your logo now.' => '',
  'You\'re using no logo at the moment. Upload your logo now.' => 'شما در حال حاضر از هیچ لوگویی استفاده‌نمی‌کنید. لوگوی خود را بارگذاری کنید.',
  'never' => 'هرگز',
);
